==> abcl-0.0.9.tar.gz: abcl-0.0.9/src/org/armedbear/lisp/server_socket_close.java <==
/*
 * server_socket_close.java
 *
 * Copyright (C) 2004 Peter Graves
 * $Id: server_socket_close.java,v 1.2 2004/11/03 15:39:02 piso Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.armedbear.lisp;

import java.net.ServerSocket;

// ### %server-socket-close
public final class server_socket_close extends Primitive
{
    private server_socket_close()
    {
        super("%server-socket-close", PACKAGE_SYS, false, "socket");
    }

    public LispObject execute(LispObject first)
        throws ConditionThrowable
    {
        try {
	    ServerSocket serverSocket = (ServerSocket) JavaObject.getObject(first);
	    serverSocket.close();
	    return T;
        }
        catch (Exception e) {
            return signal(new LispError(e.getMessage()));
        }
    }

    private static final Primitive SERVER_SOCKET_CLOSE = new server_socket_close();
}

==> abcl-0.0.10.tar.gz: abcl-0.0.10/src/org/armedbear/lisp/server_socket_close.java <==
/*
 * server_socket_close.java
 *
 * Copyright (C) 2004 Peter Graves
 * $Id: server_socket_close.java,v 1.3 2007/02/23 21:17:36 piso Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.armedbear.lisp;

import java.net.ServerSocket;

// ### %server-socket-close
public final class server_socket_close extends Primitive
{
    private server_socket_close()
    {
        super("%server-socket-close", PACKAGE_SYS, false, "socket");
    }

    public LispObject execute(LispObject first)
        throws ConditionThrowable
    {
        try {
	    ServerSocket serverSocket = (ServerSocket) JavaObject.getObject(first);
	    serverSocket.close();
	    return T;
        }
        catch (Exception e) {
            return error(new LispError(e.getMessage()));
        }
    }

    private static final Primitive SERVER_SOCKET_CLOSE = new server_socket_close();
}
